@@ -99,6 +99,7 @@ impl Drop for SingleSessionToken {
 /// Bluetooth session.
 ///
 /// Encapsulates a connection to the system Bluetooth daemon.
+#[cfg_attr(docsrs, doc(cfg(feature = "bluetoothd")))]
 pub struct Session {
     inner: Arc<SessionInner>,
 }
@@ -110,6 +111,7 @@ impl Debug for Session {
 }
 
 /// Bluetooth session event.
+#[cfg_attr(docsrs, doc(cfg(feature = "bluetoothd")))]
 #[derive(Clone, Debug, Eq, PartialEq)]
 pub enum SessionEvent {
     /// Adapter added.
@@ -192,7 +194,7 @@ impl Session {
 
     /// Stream adapter added and removed events.
     pub async fn events(&self) -> Result<impl Stream<Item = SessionEvent>> {
-        let obj_events = self.inner.events(adapter::PREFIX.into(), true).await?;
+        let obj_events = self.inner.events(adapter::PATH.into(), true).await?;
         let events = obj_events.filter_map(|evt| async move {
             match evt {
                 Event::ObjectAdded { object, interfaces }
